jacinle.comm.distrib.controller
===============================

.. automodule:: jacinle.comm.distrib.controller

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      BroadcastMessage
      ControlMessage
      Controller
      ControllerPeer
      ControllerPipeStorage
      PipePeer
      UnicastMessage
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      control
   
   

   
   
   








.. rubric:: Class BroadcastMessage
.. autoclass:: BroadcastMessage
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ControlMessage
.. autoclass:: ControlMessage
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Controller
.. autoclass:: Controller
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ControllerPeer
.. autoclass:: ControllerPeer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ControllerPipeStorage
.. autoclass:: ControllerPipeStorage
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class PipePeer
.. autoclass:: PipePeer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class UnicastMessage
.. autoclass:: UnicastMessage
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: control


